@@ -273,7 +273,7 @@ class TestCLI:
     ):
         """Test command with requirements file"""
         requirements_file = tmp_path / "requirements.txt"
-        requirements_file.write_text("requests==2.28.0\nnumpy>=1.20.0")
+        requirements_file.write_text("requests\nnumpy>=1.20.0")
 
         mock_args.file = str(valid_python_file)
         mock_args.requirements = str(requirements_file)
